@@ -1,14 +1,13 @@
 /**********************************************************************
- * $Id: SIRtree.h 2556 2009-06-06 22:22:28Z strk $
  *
  * GEOS - Geometry Engine Open Source
- * http://geos.refractions.net
+ * http://geos.osgeo.org
  *
  * Copyright (C) 2006 Refractions Research Inc.
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU Lesser General Public Licence as published
- * by the Free Software Foundation. 
+ * by the Free Software Foundation.
  * See the COPYING file for more information.
  *
  **********************************************************************/
@@ -54,9 +53,9 @@ public:
 	 * Constructs an SIRtree with the given maximum number of child nodes
 	 * that a node may have
 	 */
-	SIRtree(size_t nodeCapacity);
+	SIRtree(std::size_t nodeCapacity);
 
-	virtual ~SIRtree();
+	~SIRtree() override;
 
 	void insert(double x1, double x2, void* item);
 
@@ -82,41 +81,30 @@ protected:
 
 	class SIRIntersectsOp:public AbstractSTRtree::IntersectsOp {
 	public:
-		bool intersects(const void* aBounds, const void* bBounds);
+		bool intersects(const void* aBounds, const void* bBounds) override;
 	};
 
 	/** \brief
 	 * Sorts the childBoundables then divides them into groups of size M, where
 	 * M is the node capacity.
 	 */
-	std::auto_ptr<BoundableList> createParentBoundables(
-			BoundableList* childBoundables, int newLevel);
+	std::unique_ptr<BoundableList> createParentBoundables(
+			BoundableList* childBoundables, int newLevel) override;
 
-	AbstractNode* createNode(int level);
+	AbstractNode* createNode(int level) override;
 
-	IntersectsOp* getIntersectsOp() {return intersectsOp;};
+	IntersectsOp* getIntersectsOp() override {return intersectsOp;}
 
-	std::auto_ptr<BoundableList> sortBoundables(const BoundableList* input);
+	std::unique_ptr<BoundableList> sortBoundables(const BoundableList* input) override;
 
 private:
 
 	IntersectsOp* intersectsOp;
 };
-	
+
 
 } // namespace geos::index::strtree
 } // namespace geos::index
 } // namespace geos
 
 #endif // GEOS_INDEX_STRTREE_SIRTREE_H
-
-/**********************************************************************
- * $Log$
- * Revision 1.2  2006/06/12 10:49:43  strk
- * unsigned int => size_t
- *
- * Revision 1.1  2006/03/21 10:47:34  strk
- * indexStrtree.h split
- *
- **********************************************************************/
-
